//////////
// item //
//////////
datablock ItemData(ChicagoPizzaItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./Model/ChicagoPizza.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Chicago Pizza";
	iconName = "./IMG/icon_ChicagoPizza";
	doColorShift = false;

	 // Dynamic properties defined by the scripts
	image = ChicagoPizzaImage;
	canDrop = true;
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(ChicagoPizzaImage)
{
   // Basic Item properties
   shapeFile = "./Model/ChicagoPizza.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";
   eyeOffset = 0; //"0.7 1.2 -0.5";
   rotation = eulerToMatrix( "0 0 0" );

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this weapon doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = true;

   // Add the WeaponImage namespace as a parent, WeaponImage namespace
   // provides some hooks into the inventory system.
   className = "WeaponImage";

   // Projectile && Ammo.
   item = ChicagoPizzaItem;
   ammo = " ";
   projectile = ChicagoPizzaProjectile;
   projectileType = Projectile;

	casing = gunShellDebris;
	shellExitDir        = "0.2 0 1.0";
	shellExitOffset     = "0 0 0";
	shellExitVariance   = 15.0;	
	shellVelocity       = 7.0;

   //melee particles shoot from eye node for consistancy
   melee = false;
   //raise your arm up or not
   armReady = true;

   doColorShift = false;

   //casing = " ";

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.25;
	stateTransitionOnTimeout[0]       = "Ready";
	stateSequence[0]				= "Fire";
	stateScript[0]					= "onActivate";
	stateSound[0]					= ChicagoPizzaDrawSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "Fire";
	stateAllowImageChange[1]         = true;
	stateSequence[1]	= "Ready";

	stateName[2]                    = "Fire";
	stateTransitionOnTimeout[2]     = "Smoke";
	stateTimeoutValue[2]            = 0.04;
	stateFire[2]                    = true;
	stateAllowImageChange[2]        = false;
	stateSequence[2]                = "Fire";
	stateEjectShell[2]              = true;
	stateScript[2]                  = "onFire";
	stateWaitForTimeout[2]			= true;
	stateEmitter[2]					= ChicagoPizzaMuzzleEmitter;
	stateEmitterTime[2]				= 0.05;
	stateEmitterNode[2]				= "muzzleNode";
	stateSound[2]					= ChicagoPizzaFireSound;

	stateName[3] = "Smoke";
	stateEmitter[3]					= gunSmokeEmitter;
	stateEmitterTime[3]				= 0.12;
	stateEmitterNode[3]				= "muzzleNode";
	stateWaitForTimeout[3]			= false;
	stateTimeoutValue[3]            = 0.01;
	stateTransitionOnTimeout[3]     = "Down";
	stateTransitionOnTriggerDown[3] = "Fire";
	
	stateName[4]	= "Down";
	stateScript[4]	= "onDown";
	stateTimeoutValue[4]	= 0.2;
	stateTransitionOnTimeout[4]	= "Ready";
	stateSound[2]	= ChicagoPizzaEndSound;
};

function ChicagoPizzaImage::onActivate(%this,%obj,%slot)
{
	%obj.playthread(0, plant);
}

function ChicagoPizzaImage::onFire(%this,%obj,%slot)
{
	%projectile = %this.Projectile;
	%spread = 0.0018;
	%shellcount = 1;

	for(%shell=0; %shell<%shellcount; %shell++)
	{
		%vector = %obj.getMuzzleVector(%slot);
		%objectVelocity = %obj.getVelocity();
		%vector1 = VectorScale(%vector, %projectile.muzzleVelocity);
		%vector2 = VectorScale(%objectVelocity, %projectile.velInheritFactor);
		%velocity = VectorAdd(%vector1,%vector2);
		%x = (getRandom() - 0.5) * 10 * 3.1415926 * %spread;
		%y = (getRandom() - 0.5) * 10 * 3.1415926 * %spread;
		%z = (getRandom() - 0.5) * 10 * 3.1415926 * %spread;
		%mat = MatrixCreateFromEuler(%x @ " " @ %y @ " " @ %z);
		%velocity = MatrixMulVector(%mat, %velocity);

		%p = new (%this.projectileType)()
		{
			dataBlock = %projectile;
			initialVelocity = %velocity;
			initialPosition = %obj.getMuzzlePoint(%slot);
			sourceObject = %obj;
			sourceSlot = %slot;
			client = %obj.client;
		};
		MissionCleanup.add(%p);
		%obj.playThread(0, shiftRight);
		%obj.playThread(2, shiftLeft);
	}
	
}

function ChicagoPizzaImage::onDown(%this,%obj,%slot)
{
	%obj.playthread(0, jump);
}